<?php
/*
Plugin Name: Terribletracker - Google Analytics tracking
Plugin URI: https://terribletraffic.com
Description: Simply enter your UA-code to integrate Google Analytics into your WordPress site. Build for Site Speed: extremely lightweight, no clutter, no unnecessary code. Just tracking.
Author: terribletraffic
Author URI: https://terribletraffic.com/
Version: 1.1.0
Text Domain: terribletraffic
License: GPL2 - http://www.gnu.org/licenses/gpl-2.0.html
*/



// CREATE HANDY CONSTANTS
if(!defined('terrible_URL'))
	define('terrible_URL', plugin_dir_url( __FILE__ ));
if(!defined('terrible_PATH'))
	define('terrible_PATH', plugin_dir_path( __FILE__ ));


// INCLUDE REST OF PHP FILES
require_once( plugin_dir_path( __FILE__ ) . 'tracking.php');



/**
 * Register a custom menu page.
 */
function terrible_add_settings_page()
	{
		$TTicon = terrible_URL . 'assets/images/icon.svg';
		
    	add_menu_page( 
        	__( 'Terribletracker', 'terribletraffic' ),
        	'Terribletracker',
        	'manage_options',
        	'settingspage',
        	'terrible_settings_page',
        	'' /* should be icon WIP */,
        	6
    	); 
    	
	}

 
// build settings page TOPLEVEL
function terrible_settings_page(){	
    ?>
    	<div class='TTwrap'>
    		<div class='TTmain'>
    		<img src=
    		<?php echo terrible_URL . 'assets/images/icon.svg';
    		?> class='TTlogo' />
    		<h1>Welcome to Terribletracker</h1>
    		<p>Lightweight Google Analytics tracking. <a href='https://terribletraffic.com/contact-us/' target=_blank>Feedback? We'd love to hear it - please contact us »</a></p>
    		<p>Let's get started.</p>
    		<div class='TTfeedback'>
    		<?php
    		$ua_code = get_option('ua_code');
    		
    		if ( isset($ua_code) ) {
    			if( $ua_code == 'format should be UA-12345-12' ){
    					echo "<div class='red'><b>Not tracking!</b> - UA-code format should be UA-XXXX-X. You can find your UA-code by logging into <a href='http://analytics.google.com' target=_blank>Google Analytics</a>, go to Admin -> Tracking Info -> Tracking Code.</div>";
    				}
    			}
    		else {
    				echo "<div class='green'><b>Not tracking!</b> - Please enter your UA-code below to start tracking</div>";
    			}
    		?>
			</div>
    		<form method="post" action="options.php">
    		
    		    <?php
                
                    //add_settings_section callback is displayed here. For every new section we need to call settings_fields.
                    settings_fields("tracking_settings");
                    
                    // all the add_settings_field callbacks is displayed here
                    do_settings_sections("settingspage");
                
                    // Add the submit button to serialize the options
                    submit_button(); 
                    
                ?>   
    		
			</form>
			</div>
    	</div>
    	
    <?php
}


function terrible_ua_code_input(){
	// create input field for ua_code
    ?>
        <input type="text" name="ua_code" id="ua_code" value="<?php echo get_option('ua_code'); ?>" />
    <?php
}

function isThisAnUAcode($input){
		return (bool) preg_match('/^ua-\d{4,10}(-\d{1,4})?$/i', $input);
	}
	
function terrible_validate_ua_code( $input ){
	// clean up user input from ua_code_input()
	$output;
	
	if( ISSET($input)){
		
		$valid = isThisAnUAcode($input);
		
			if ( $valid ){
					$output = $input;
				}
			else
				{
					$output = "format should be UA-12345-12";
				}
		}
	return $output;
}

// deprecated
function display_tracking_settings(){}

function terrible_settings_init(){
	// tracking setup
    //section name, display name, callback to print description of section, page to which section is attached.
	add_settings_section("tracking_settings", "Tracking Settings", "display_tracking_settings", "settingspage");
	//setting name, display name, callback to print form element, page in which field is displayed, section to which it belongs.
    add_settings_field("ua_code", "Google Analytics UA-code", "terrible_ua_code_input", "settingspage", "tracking_settings");
    //section name, form element name, callback for sanitization
    register_setting("tracking_settings", "ua_code", "terrible_validate_ua_code");

}



function terrible_load_styles() { 
	
	// LOCATION OF STYLESHEETS
	$css = terrible_URL . 'assets/style.css';
	// REGISTER STYLE
	wp_register_style( 'admincss', $css );

    
	// LOAD $GA IN HEADER
    wp_enqueue_style( 'admincss');   
}


add_action( 'admin_init', 'terrible_settings_init' );
add_action( 'admin_menu', 'terrible_add_settings_page' );
add_action( 'admin_enqueue_scripts', 'terrible_load_styles' );

?>